@@ -29,6 +29,11 @@
 #undef HAVE_GETTEXT
 #undef HAVE_LC_MESSAGES
 #undef HAVE_STPCPY
+#undef HAVE_INT_HASH
+#undef HAVE_STRUCT_ICMP
+#undef HAVE_INET
+#undef HAVE_IPX
+#undef HAVE_INET6
 
 ^L
 /* Leave that blank line there!!  Autoheader needs it.
