@@ -1,5 +1,5 @@
 /*
- * $Id: date.h,v 1.4 1998/04/16 14:49:15 jochen Exp $
+ * $Id: date.h,v 1.5 1998/06/14 21:18:33 gregm Exp $
  * GXSNMP - An snmp managment application
  * Copyright (C) 1998 Gregory McLean
  *
@@ -22,7 +22,17 @@
 #ifndef __DATE_FUNC_H_
 #define __DATE_FUNC_H_
 
-char          *sql_time_str               (char *buf);
+/*
+ * Return a string all ready to be stuffed into a sql database.
+ */
+char          *db_time_str               (char *buf);
+
 #endif
 
 /* EOF */
+
+
+
+
+
+
