@@ -1,5 +1,5 @@
 /*
- * $Id: gui.c,v 1.13 1998/08/01 20:04:27 gregm Exp $
+ * $Id: gui.c,v 1.15 1998/08/10 23:09:42 gregm Exp $
  * GXSNMP - An snmp managment application
  * Copyright (C) 1998 Gregory McLean
  *
@@ -279,14 +279,26 @@ notebook_tab (const char *label)
   gtk_box_pack_start (GTK_BOX (tab_box), pixmap, FALSE, TRUE, 0);
   gtk_misc_set_padding (GTK_MISC (pixmap), 3, 1);
   tab_label = gtk_label_new (label);
-  gtk_misc_set_padding (GTK_MISC (label), 10, 0);
+  gtk_misc_set_padding (GTK_MISC (tab_label), 10, 0);
   gtk_box_pack_start (GTK_BOX (tab_box), tab_label, FALSE, TRUE, 0);
   gtk_widget_show_all (tab_box);
   return tab_box;
 }
 
+GtkWidget * 
+get_widget (GtkWidget *widget, const gchar *name)
+{
+  GtkWidget   *found;
+
+  g_return_val_if_fail (GTK_IS_OBJECT (widget), NULL);
+
+  if (widget->parent)
+    widget = gtk_widget_get_toplevel (widget);
+  found = gtk_object_get_data (GTK_OBJECT (widget), name);
+  if (!found)
+    {
+      return NULL;
+    }
+  return found;
+}
 /* EOF */
-
-
-
-
