@@ -1,5 +1,5 @@
 /*
- * $Id: host_list.c,v 1.31 1998/06/04 00:15:48 unammx Exp $
+ * $Id: host_list.c,v 1.34 1998/07/27 18:41:25 jochen Exp $
  * GXSNMP -- An snmp management application
  *
  * This program is free software; you can redistribute it and/or modify
@@ -16,14 +16,14 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc.,  59 Temple Place - Suite 330, Cambridge, MA 02139, USA.
  *
- * Host list specific functions
+ * Host list UI specific functions
  */
 #ifndef lint
 static char const copyright[] =
 "@(#) Copyright (c) 1998 Gregory McLean";
 #endif
 static char const rcsid[] =
- "$Id: host_list.c,v 1.31 1998/06/04 00:15:48 unammx Exp $";
+ "$Id: host_list.c,v 1.34 1998/07/27 18:41:25 jochen Exp $";
 #include <gtk/gtk.h>
 #include <sys/types.h>
 #include <sys/socket.h>
@@ -526,6 +526,8 @@ add_null_var (GSList **objs, GSList **entry, char *what, GtkWidget *name)
   obj->request = 0;
   obj->type    = SNMP_NULL;
   obj->id_len  = SNMP_SIZE_OBJECTID;
+  obj->id      = g_malloc(SNMP_SIZE_OBJECTID);
+
   if (!read_objid (what, obj->id, &obj->id_len))
     {
       update_app_stat ("Invaild snmp variable \"%s\"!", what);
@@ -585,6 +587,7 @@ refresh_info (hosts *entry)
       host->hl_snmp.done_callback = update_widget;
       host->hl_snmp.time_callback = destroy_widget;
       app_info->sinf_panel->irequest = g_async_get(&host->hl_snmp, objs);
+      /* FIXME: irequest might be NULL due to error */
     } else {
       g_print ("Null pointer??\n");
     }
@@ -937,8 +940,8 @@ static GnomeUIInfo file_menu[] = {
   { GNOME_APP_UI_SEPARATOR },  
   { GNOME_APP_UI_ITEM, N_("Close"), NULL, route_close_button_cb, NULL, NULL,
     GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_EXIT, 0, 0, NULL },
-  { GNOME_APP_UI_ITEM, N_("Exit"), NULL, route_exit_menu_cb, NULL, NULL,
-    GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_EXIT, 'X', GDK_CONTROL_MASK,
+  { GNOME_APP_UI_ITEM, N_("Quit"), NULL, route_exit_menu_cb, NULL, NULL,
+    GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_EXIT, 'Q', GDK_CONTROL_MASK,
     NULL },
   { GNOME_APP_UI_ENDOFINFO }
 };
@@ -1188,6 +1191,7 @@ update_ctable (host_snmp *host, void *magic, SNMP_PDU *spdu, GSList *objs)
               nobj->request = 0;
               nobj->type    = SNMP_NULL;
               nobj->id_len  = obj->id_len;
+              nobj->id      = g_malloc(obj->id_len * sizeof(ulong));
               g_memmove(nobj->id, obj->id, obj->id_len * sizeof(ulong));
               nobjs  = g_slist_append(nobjs, nobj);
               j++;
@@ -1324,6 +1328,7 @@ static char *interface_labels[] = {
 static icol_sizes[ELEMENTS(interface_labels)];
 static interface_panel *int_panel = NULL;
 static hosts *interface_host = NULL;
+
 /*
  * Menus
  */
@@ -1332,7 +1337,7 @@ static GnomeUIInfo i_file_menu[] = {
   { GNOME_APP_UI_ITEM, N_("Close"), NULL, interface_close_button_cb,
     NULL, NULL,
     GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_BLANK, 0, 0, NULL },
-  { GNOME_APP_UI_ITEM, N_("Exit"), NULL, NULL,
+  { GNOME_APP_UI_ITEM, N_("Quit"), NULL, NULL,
     NULL, NULL,
     GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_BLANK, 0, 0, NULL },
   { GNOME_APP_UI_ENDOFINFO },
@@ -1669,6 +1674,7 @@ update_interface_table (host_snmp *host, void *magic, SNMP_PDU *spdu,
 		    nobj->request  = 0;
 		    nobj->type     = SNMP_NULL;
 		    nobj->id_len   = obj->id_len;
+		    nobj->id       = g_malloc(obj->id_len * sizeof (ulong));
 		    g_memmove (nobj->id, obj->id, obj->id_len * sizeof (ulong));
 		    nobjs          = g_slist_append (nobjs, nobj);
 		    j++;
@@ -1942,21 +1948,23 @@ update_int_detail (host_snmp *host, void *magic, SNMP_PDU *spdu, GSList *objs)
 
      int_detail_panel->request = NULL;
      entry = (GSList *)magic;
-     if (spdu->request.error_status) {
-	  g_slist_free (entry);
-	  return;
-     }
+     if (spdu->request.error_status) 
+       {
+	 g_slist_free (entry);
+	 return;
+       }
      myobj = objs;
      while (myobj) {
        obj = (struct _SNMP_OBJECT *)myobj->data;
        g_snmp_printf (buf, sizeof(buf), obj);
        myentry = entry;
-       while (myentry) {
-	 var = (oidentry *)myentry->data;
-	 if (!memcmp (obj->id, var->id, var->id_len * (sizeof (gulong))))
-	   gtk_entry_set_text (GTK_ENTRY (var->name), buf);
-	 myentry = myentry->next;
-       }
+       while (myentry) 
+	 {
+	   var = (oidentry *)myentry->data;
+	   if (!memcmp (obj->id, var->id, var->id_len * (sizeof (gulong))))
+	     gtk_entry_set_text (GTK_ENTRY (var->name), buf);
+	   myentry = myentry->next;
+	 }
        myobj = myobj->next;
      }
      g_slist_free (entry);
@@ -1986,11 +1994,12 @@ int_detail_reload_button_cb (GtkWidget *widget, gpointer data)
 static void
 int_detail_abort_button_cb (GtkWidget *widget, gpointer data)
 {
-     if (int_detail_panel) {
-	  if (int_detail_panel->request)
-	       g_remove_request (int_detail_panel->request);
-	  int_detail_panel->request = NULL;
-     }
+  if (int_detail_panel) 
+    {
+      if (int_detail_panel->request)
+	g_remove_request (int_detail_panel->request);
+      int_detail_panel->request = NULL;
+    }
 }
 
 
@@ -2000,26 +2009,27 @@ int_detail_abort_button_cb (GtkWidget *widget, gpointer data)
 void
 open_int_detail_panel ()
 {
-     if (!int_detail_panel)
-	  create_int_detail_panel ();
-     else
-	  if (!GTK_WIDGET_VISIBLE (int_detail_panel->window))
-	       gtk_widget_show_all (int_detail_panel->window);
-     reset_int_detail_panel ();
+  if (!int_detail_panel)
+    create_int_detail_panel ();
+  else
+    if (!GTK_WIDGET_VISIBLE (int_detail_panel->window))
+      gtk_widget_show_all (int_detail_panel->window);
+  reset_int_detail_panel ();
 }
 
 void
 destroy_int_detail_panel ()
 {
-     if (int_detail_panel) {
-	  if (int_detail_panel->request)
-	       g_remove_request (int_detail_panel->request);
-	  if (int_detail_panel->update_id)
-	    gtk_timeout_remove (int_detail_panel->update_id);
-	  gtk_widget_destroy (int_detail_panel->window);
-	  g_free (int_detail_panel);
-	  int_detail_panel = NULL;
-     }
+     if (int_detail_panel) 
+       {
+	 if (int_detail_panel->request)
+	   g_remove_request (int_detail_panel->request);
+	 if (int_detail_panel->update_id)
+	   gtk_timeout_remove (int_detail_panel->update_id);
+	 gtk_widget_destroy (int_detail_panel->window);
+	 g_free (int_detail_panel);
+	 int_detail_panel = NULL;
+       }
 }
 
 void 
