@@ -1,5 +1,5 @@
 /*
- * $Id: main.c,v 1.46 1998/08/01 20:04:28 gregm Exp $
+ * $Id: main.c,v 1.50 1998/08/13 22:21:25 gregm Exp $
  * GXSNMP -- An snmp mangament application
  * Copyright (C) 1998 Gregory McLean
  *
@@ -25,10 +25,11 @@ static char const copyright[] =
 "@(#) Copyright (c) 1998 Gregory McLean";
 #endif
 static char const rcsid[] =
- "$Id: main.c,v 1.46 1998/08/01 20:04:28 gregm Exp $";
+ "$Id: main.c,v 1.50 1998/08/13 22:21:25 gregm Exp $";
 #include <config.h>
 #include "main.h"
 #include <gtkhost.h>
+#include "net_map.h"
 
 /*
  * Local functions 
@@ -48,8 +49,6 @@ static void menuitem_clicked    (GtkWidget *widget,
 				 gpointer  data);
 static gint button_press_event  (GtkWidget *widget,
 				 GdkEventButton *event);
-static gint motion_notify_event (GtkWidget *widget,
-				 GdkEventMotion *event);
 static gint panel_delete_cb     (GtkWidget *widget,
 				 GdkEvent  *e,
 				 gpointer  data);
@@ -58,7 +57,6 @@ gint draw_host                  (GtkWidget *widget,
 
 static GtkWidget                *status;
 
-static char *logo_pixmap_filename;
 
 gxsnmp *app_info;
 
@@ -134,7 +132,7 @@ gtk_menu_factory_parse_accelerator (char   *accelerator,
         }
       else
         {
-          done = TRUE;
+         done = TRUE;
           *accelerator_key = accelerator[0];
         }
     }
@@ -216,34 +214,6 @@ make_toolbar (GtkWidget *window)
 
   toolbar = gtk_toolbar_new (GTK_ORIENTATION_VERTICAL, GTK_TOOLBAR_BOTH);
 
-  kludge = gnome_unconditional_pixmap_file ("add_host.xpm");
-  gtk_toolbar_append_item (GTK_TOOLBAR (toolbar),
-			   _("Add host"), _("Add a new host to the database"), 
-			   NULL,
-			   new_pixmap (kludge, window->window, 
-				       &window->style->bg[GTK_STATE_NORMAL]),
-			   (GtkSignalFunc) open_add_host_panel, NULL);
-  kludge = gnome_unconditional_pixmap_file ("del_host.xpm");
-  gtk_toolbar_append_item (GTK_TOOLBAR (toolbar),
-			   _("Delete host"), 
-                           _("Remove a host from the database"),
-			   NULL,
-			   new_pixmap (kludge, window->window,
-				       &window->style->bg[GTK_STATE_NORMAL]),
-			   (GtkSignalFunc) delete_host_cb, NULL);
-  gtk_toolbar_append_item (GTK_TOOLBAR (toolbar),
-			   _("Host List"), _("Open the list of known hosts"),
-			   NULL,
-			   gnome_stock_pixmap_widget (window,
-				              GNOME_STOCK_PIXMAP_NEW),
-			   (GtkSignalFunc) hlist_panel_open, NULL);
-  gtk_toolbar_append_item (GTK_TOOLBAR (toolbar),
-			   _("Network List"), 
-                           _("Open the list of known networks"),
-			   NULL,
-			   gnome_stock_pixmap_widget (window,
-				              GNOME_STOCK_PIXMAP_NEW),
-			   (GtkSignalFunc) open_network_panel, NULL);
   gtk_toolbar_append_item (GTK_TOOLBAR (toolbar),
 			   _("Mib Browser"), _("Open the mib browser"),
 			   NULL,
@@ -344,52 +314,6 @@ create_main_panel ()
     gtk_box_pack_start (GTK_BOX (hbox), right_box, TRUE, TRUE, 0);
     gtk_widget_show (right_box);
 
-    scrolled_window = gtk_scrolled_window_new (NULL, NULL);
-    gtk_container_border_width (GTK_CONTAINER (scrolled_window), 10);
-    gtk_widget_set_usize (GTK_WIDGET (scrolled_window), 600, 600);
-    gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (scrolled_window),
-				    GTK_POLICY_AUTOMATIC, GTK_POLICY_ALWAYS);
-    gtk_box_pack_start (GTK_BOX (right_box), scrolled_window, TRUE, TRUE, 0);
-    gtk_widget_show (scrolled_window);
-    
-    app_info->eventbox = gtk_event_box_new ();
-    gtk_widget_set_usize (app_info->eventbox, 1600, 1024);
-    gtk_widget_set_events (app_info->eventbox,
-			   GDK_BUTTON_PRESS_MASK |
-			   GDK_POINTER_MOTION_MASK |
-			   GDK_POINTER_MOTION_HINT_MASK );
-    gtk_container_add (GTK_CONTAINER (scrolled_window), app_info->eventbox);
-    gtk_widget_realize (app_info->eventbox);
-    gdk_window_set_cursor (app_info->eventbox->window, gdk_cursor_new 
-			   (GDK_CROSSHAIR));
-    /*
-     * Set up the backing pixmap for our network map
-     */
-    app_info->pixmap = gdk_pixmap_new (app_info->eventbox->window, 1600, 
-				       1024, -1);
-    gdk_window_set_back_pixmap (app_info->eventbox->window, app_info->pixmap, 
-				FALSE);
-    gdk_draw_rectangle (app_info->pixmap,
-			app_info->eventbox->style->white_gc,
-			TRUE,
-			0, 0,
-			1600, 1024);
-    gtk_widget_show (app_info->eventbox);
-
-    scrolled = gtk_sbox_new ();
-    gtk_widget_set_usize (scrolled, 1600, 1024);
-    gtk_container_add (GTK_CONTAINER (app_info->eventbox), scrolled);
-    gtk_widget_show (scrolled);
-
-    gtk_signal_connect (GTK_OBJECT (app_info->eventbox), "motion_notify_event",
-			GTK_SIGNAL_FUNC (motion_notify_event),
-			NULL);
-    gtk_signal_connect (GTK_OBJECT (app_info->eventbox), "button_press_event",
-			GTK_SIGNAL_FUNC (button_press_event), 
-			NULL);
-
-    gtk_widget_show (scrolled);
-
     bar = gtk_hseparator_new ();
     gtk_box_pack_start (GTK_BOX (vbox), bar, FALSE, FALSE, 0);
     gtk_widget_show (bar);
@@ -402,23 +326,10 @@ create_main_panel ()
     gtk_container_add (GTK_CONTAINER (hbox), toolbar);
     gtk_widget_show (toolbar);
 
-    app_info->mouse_stat = gtk_statusbar_new ();
-    gtk_box_pack_start (GTK_BOX (left_box), app_info->mouse_stat,
-			FALSE, FALSE, 0);
-    gtk_widget_show (app_info->mouse_stat);
-    gtk_widget_realize (app_info->window);
-    logo_pixmap_filename = gnome_unconditional_pixmap_file ("logo_v.xpm");
-    logo = new_pixmap (logo_pixmap_filename, app_info->window->window, 
-		       &app_info->window->style->bg[GTK_STATE_NORMAL]);
-    gtk_box_pack_start (GTK_BOX (left_box), logo, TRUE, TRUE, 2);
-    gtk_widget_show (logo);
     app_info->app_stat = gtk_statusbar_new ();
     app_info->app_stat_id = gtk_statusbar_get_context_id 
                             (GTK_STATUSBAR(app_info->app_stat),
 			     "app_stat");
-    app_info->mouse_stat_id = gtk_statusbar_get_context_id (
-			      GTK_STATUSBAR(app_info->mouse_stat),
-			      "mouse_stat");
     gtk_box_pack_start (GTK_BOX (vbox), app_info->app_stat, FALSE, FALSE, 0);
 #ifdef GTK_HAVE_FEATURES_1_1_0
     gtk_window_add_accel_group (GTK_WINDOW (app_info->window),
@@ -427,7 +338,6 @@ create_main_panel ()
     gtk_window_add_accelerator_table (GTK_WINDOW (app_info->window),
 				      app_info->accel_table);
 #endif
-    g_print ("Showing map window...\n");
     gtk_widget_show_all (app_info->window);
     init_pixmap_d (app_info->app_stat);
 }
@@ -451,6 +361,7 @@ quit_button_cb (GtkWidget *widget,
   destroy_control_panel ();
   destroy_edit_panel ();
   destroy_route_panel ();
+  destroy_map_panel ();
   if (app_info->conf_panel != NULL)
     {
       gtk_widget_destroy (app_info->conf_panel->window);
@@ -597,39 +508,6 @@ button_press_event (GtkWidget *widget,
   return TRUE;
 }
 
-static gint
-motion_notify_event ( GtkWidget *widget, GdkEventMotion *event)
-{
-  int x, y;
-  static gint statusid;
-
-  char buf[80];
-  GdkModifierType state;
- 
-  if (event->is_hint)
-    gdk_window_get_pointer (event->window, &x, &y, &state);
-  else
-    {
-      x = event->x;
-      y = event->y;
-      state = event->state;
-    }
-  if (state & GDK_BUTTON2_MASK && app_info->pixmap != NULL)
-    {
-      if(app_info->current_host != NULL)
-	{
-	  gtk_widget_set_uposition (GTK_WIDGET(app_info->current_host),
-				    x, y);
-	}
-    }
-  sprintf (buf, "%d x %d", x, y);
-  gtk_statusbar_pop (GTK_STATUSBAR (app_info->mouse_stat),
-		     app_info->mouse_stat_id);
-  gtk_statusbar_push (GTK_STATUSBAR (app_info->mouse_stat),
-		      app_info->mouse_stat_id, buf);
-  return TRUE;
-}
-
 void
 update_app_stat (gchar *msg, ...)
 {
@@ -661,8 +539,10 @@ draw_host (GtkWidget *widget, hosts *hentry)
       new = hl_add_host (hentry);
       if (new != NULL)
 	{
-	  new->widget = new_host_widget (new);
-	  if (!GTK_WIDGET_REALIZED (scrolled))
+	  
+	  /*	  new->widget = new_host_widget (new); */
+          map_add_host (new, -1, -1);
+	  /*	  if (!GTK_WIDGET_REALIZED (scrolled))
 	    gtk_widget_realize (scrolled);
 	  color = get_color (HOST_UP_COLOR);
 	  gdk_color_alloc (gdk_window_get_colormap (scrolled->window),
@@ -677,16 +557,20 @@ draw_host (GtkWidget *widget, hosts *hentry)
 				 gdk_cursor_new (GDK_HAND1) );
 	  gtk_signal_connect (GTK_OBJECT (new->widget), "button_press_event",
 			      GTK_SIGNAL_FUNC (host_button_cb),
-			      NULL);
+			      NULL); */
 	  new->snmp_running = FALSE;
+	  /*
 	  gtk_object_set_data (GTK_OBJECT (new->widget),"host_entry", new);
+	  */
 	  if (app_info->hlist_pane != NULL)
 	    list_add (NULL, new, NULL);
 	  if (app_info->brows_panel != NULL)
 	    browser_add_host (new->hl_snmp.name);
+	  /*
 	  gtk_widget_show (new->widget);
 	  gtk_widget_set_style (new->widget, &style);
 	  app_info->current_host = new->widget;
+	  */
 	  app_info->host_count++;
 	  update_known_hosts (app_info->host_count);
 	}
@@ -778,6 +662,7 @@ main (int argc, char *argv[])
       app_info->snmp_running = 0;
     }
   create_main_panel ();
+  open_map_panel ();
   open_control_panel ();
   sql_load_host_table ();
 
