@@ -1,5 +1,5 @@
 /*
- * $Id: snmp_host.h,v 1.17 1998/07/29 21:18:51 jochen Exp $
+ * $Id: snmp_host.h,v 1.21 1998/08/12 00:54:01 gregm Exp $
  * GXSNMP -- An snmp management application
  * Copyright (C) 1998 Gregory McLean
  *
@@ -27,6 +27,8 @@
 #include <gtk/gtk.h>
 #include <netdb.h>
 #include <netinet/in.h>
+#include "net.h"
+
 /* 
  * For the add host dialog 
  */
@@ -120,6 +122,10 @@ typedef struct _hosts {
   GList         *monitor_list;  /* A list of mibs to monitor for this host */
   GtkWidget     *widget;        /* the widget that displays this host */
   GtkWidget     *listwidget;    /* the widget on the host list for this host */
+  GnomeCanvasGroup *hl_mgroup;	/* The group for this host on the map */
+  GnomeCanvasGroup *hl_ngroup;  /* The network group that this is connected to */
+  GnomeCanvasItem  *hl_mconnection; /* The connect to the network */
+  net_entry     *hl_network;    /* network we are connected to */
   location      hl_location;    /* Where to put this host on the map */
   u_long        hl_lastsnmpif;
   time_t        hl_lastsnmp;
