@@ -1,5 +1,5 @@
 /*
- * $Id: sql_interface.c,v 1.18 1998/07/29 21:18:52 jochen Exp $
+ * $Id: sql_interface.c,v 1.19 1998/08/09 16:24:21 gregm Exp $
  * GXSNMP -- An snmp mangament application
  * Copyright (C) 1998 Gregory McLean
  *
@@ -24,7 +24,7 @@ static char const copyright[] =
 "@(#) Copyright (c) 1998 Gregory McLean";
 #endif
 static char const rcsid[] =
-"$Id: sql_interface.c,v 1.18 1998/07/29 21:18:52 jochen Exp $";
+"$Id: sql_interface.c,v 1.19 1998/08/09 16:24:21 gregm Exp $";
 
 #include "main.h"
 #include "db_interface.h"
@@ -76,6 +76,9 @@ sql_server_status (sql_server *server)
 #endif
 }
 
+/*
+ * This will return a list of available tables.
+ */
 GList *
 sql_db_list (sql_server *server)
 {
@@ -95,14 +98,6 @@ sql_db_list (sql_server *server)
 
   if (db_connect (db_connection))
     {
-#if 0
-  sql = (MYSQL *)g_malloc (sizeof(MYSQL));
-  if (mysql_connect (sql, 
-		     server->sql_host,
-		     server->sql_user,
-		     server->sql_pass))
-    {
-#endif
       sql_res = mysql_use_result (db_connection->db_handle);
       sql_res = mysql_list_dbs (db_connection->db_handle, "");
       while ( (row = mysql_fetch_row(sql_res)) )
