@@ -1,5 +1,5 @@
 /*
- * $Id: gtkhost.c,v 1.11 1998/06/14 21:18:37 gregm Exp $
+ * $Id: gtkhost.c,v 1.12 1998/08/09 16:24:24 gregm Exp $
  * GTKEXT - Extensions to The GIMP Toolkit
  * Copyright (C) 1998 Gregory McLean
  *
@@ -231,7 +231,7 @@ static gint
 gtk_host_leave_notify (GtkWidget        *widget,
 		       GdkEventCrossing *event)
 {
-  g_print ("Host Leave Notify.\n");
+/*  g_print ("Host Leave Notify.\n"); */
   return FALSE;
 }
 
@@ -256,13 +256,13 @@ gtk_host_press (GtkWidget      *widget,
 static void
 gtk_host_real_enter (GtkHost *host)
 {
-  g_print ("Real Enter\n");
+/*  g_print ("Real Enter\n"); */
 }
 
 static void 
 gtk_host_real_leave (GtkHost *host)
 {
-  g_print ("Real Leave\n");
+ /* g_print ("Real Leave\n"); */
 }
 
 static void
